# SPDX-License-Identifier: GPL-2.0-or-later

bl_info = {
    "name": "VSE ToolBox",
    "description": "In-House Video editing Tools",
    "author": "Samuel Bernou, Clement Ducarteron, Christophe Seux",
    "version": (0, 1, 0),
    "blender": (3, 4, 1),
    "location": "Sequencer",
    "warning": "",
    "category": "Sequencer",
}
    # "doc_url": "https://github.com/Pullusb/REPONAME",
    # "tracker_url": "https://github.com/Pullusb/REPONAME/issues",

import sys
from pathlib import Path
sys.modules['vse_toolbox'] = sys.modules.pop(Path(__file__).parent.name)

from vse_toolbox import panels
from vse_toolbox import preferences
from vse_toolbox import properties
from vse_toolbox import operators
from vse_toolbox.constants import ASSET_PREVIEWS
from vse_toolbox.sequencer_utils import get_active_strip


mods = (
    properties,
    preferences,
    operators,
    panels,
)

if 'bpy' in locals():
    import importlib
    for mod in mods:
        importlib.reload(mod)

import bpy

def register():
    if bpy.app.background:
        return
    
    for mod in mods:
        mod.register()

    bpy.app.handlers.frame_change_post.append(get_active_strip)

def unregister():

    bpy.utils.previews.remove(ASSET_PREVIEWS)

    if bpy.app.background:
        return
        
    bpy.app.handlers.frame_change_post.remove(get_active_strip)
    for mod in reversed(mods):
        mod.unregister()

if __name__ == "__main__":
    register()
